@@ -363,6 +363,7 @@ class Postgres(Dialect):
             "REGROLE": TokenType.OBJECT_IDENTIFIER,
             "REGTYPE": TokenType.OBJECT_IDENTIFIER,
             "FLOAT": TokenType.DOUBLE,
+            "XML": TokenType.XML,
         }
         KEYWORDS.pop("/*+")
         KEYWORDS.pop("DIV")
@@ -381,9 +382,13 @@ class Postgres(Dialect):
         }
         PROPERTY_PARSERS.pop("INPUT")
 
+        PLACEHOLDER_PARSERS = {
+            **parser.Parser.PLACEHOLDER_PARSERS,
+            TokenType.MOD: lambda self: self._parse_query_parameter(),
+        }
+
         FUNCTIONS = {
             **parser.Parser.FUNCTIONS,
-            "ASCII": exp.Unicode.from_arg_list,
             "DATE_TRUNC": build_timestamp_trunc,
             "DIV": lambda args: exp.cast(
                 binary_from_function(exp.IntDiv)(args), exp.DataType.Type.DECIMAL
@@ -454,6 +459,15 @@ class Postgres(Dialect):
             )([this, path]),
         }
 
+        def _parse_query_parameter(self) -> t.Optional[exp.Expression]:
+            this = (
+                self._parse_wrapped(self._parse_id_var)
+                if self._match(TokenType.L_PAREN, advance=False)
+                else None
+            )
+            self._match_text_seq("S")
+            return self.expression(exp.Placeholder, this=this)
+
         def _parse_operator(self, this: t.Optional[exp.Expression]) -> t.Optional[exp.Expression]:
             while True:
                 if not self._match(TokenType.L_PAREN):
@@ -533,6 +547,7 @@ class Postgres(Dialect):
         QUERY_HINTS = False
         NVL2_SUPPORTED = False
         PARAMETER_TOKEN = "$"
+        NAMED_PLACEHOLDER_TOKEN = "%"
         TABLESAMPLE_SIZE_IS_ROWS = False
         TABLESAMPLE_SEED_KEYWORD = "REPEATABLE"
         SUPPORTS_SELECT_INTO = True
@@ -798,3 +813,7 @@ class Postgres(Dialect):
                 expression.args["unit"].replace(exp.var("MONTH"))
 
             return super().interval_sql(expression)
+
+        def placeholder_sql(self, expression: exp.Placeholder) -> str:
+            this = f"({expression.name})" if expression.this else ""
+            return f"{self.NAMED_PLACEHOLDER_TOKEN}{this}s"
