@@ -9,6 +9,11 @@ class TestSpark(Validator):
     dialect = "spark"
 
     def test_ddl(self):
+        self.validate_identity("DAYOFWEEK(TO_DATE(x))")
+        self.validate_identity("DAYOFMONTH(TO_DATE(x))")
+        self.validate_identity("DAYOFYEAR(TO_DATE(x))")
+        self.validate_identity("WEEKOFYEAR(TO_DATE(x))")
+
         self.validate_identity("DROP NAMESPACE my_catalog.my_namespace")
         self.validate_identity("CREATE NAMESPACE my_catalog.my_namespace")
         self.validate_identity("INSERT OVERWRITE TABLE db1.tb1 TABLE db2.tb2")
